import rdflib
import folium

# Read RDF file
rdf_file = 'finanzamter-2024-01-28.rdf'
g = rdflib.Graph()
g.parse(rdf_file)

# Define RDF namespace
schema = rdflib.Namespace("http://schema.org/")

# Extract tax office information from RDF data
# We will use these in the pop-ups on the map later on
org_data = []
for org in g.subjects(rdflib.RDF.type, schema.Organization):
    org_info = {}
    
    # Official tax office name
    org_info['name'] = g.value(org, schema.name, None)
    
    # Address
    postal_address = g.value(org, schema.address, None)
    if postal_address:
        org_info['streetAddress'] = g.value(postal_address, schema.streetAddress, None)
        org_info['locality'] = g.value(postal_address, schema.addressLocality, None)
        org_info['postalCode'] = g.value(postal_address, schema.postalCode, None)
    
    # Coordinates
    location = g.value(org, schema.location, None)
    if location:
        geo = g.value(location, schema.geo, None)
        if geo:
            org_info['latitude'] = g.value(geo, schema.latitude, None)
            org_info['longitude'] = g.value(geo, schema.longitude, None)
    
    # Other
    org_info['phone'] = g.value(org, schema.phone, None)
    org_info['email'] = g.value(org, schema.email, None)
    org_info['url'] = g.value(org, schema.url, None)
    
    org_data.append(org_info)

# Create HTML (and table) header
html_content = """
<html>
<head><title>Tax offices in Schleswig-Holstein</title></head>
<body>
<h2>Tax offices in Schleswig-Holstein</h2>
<table border="1">
    <tr><th>Name</th><th>Street</th><th>City</th><th>Post Code</th><th>Phone</th><th>Mail</th><th>WWW</th></tr>
"""

# Create a row in the HTML tabel for each entry in the RDF file
for org in org_data:
    html_content += f"""
    <tr>
        <td>{org.get('name', 'N/A')}</td>
        <td>{org.get('streetAddress', 'N/A')}</td>
        <td>{org.get('locality', 'N/A')}</td>
        <td>{org.get('postalCode', 'N/A')}</td>
        <td>{org.get('phone', 'N/A')}</td>
        <td>{org.get('email', 'N/A')}</td>
        <td><a href="{org.get('url', '#')}">{org.get('url', 'N/A')}</a></td>
    </tr>
    """
html_content += """
</table>
</body>
</html>
"""

# Save table to file
html_file = 'output_list.html'
with open(html_file, 'w', encoding='utf-8') as f:
    f.write(html_content)

print(f"Tax office list '{html_file}' has been saved successfully")

# Create a map using folium library
# Set the center to the city of Nortorf (which is the center of 
# Schleswig-Holstein according to Google):
mymap = folium.Map(location=[54.16995, 9.85516], zoom_start=6)

# Set markers on map for all tax offices and add a popup for each POI
for org in org_data:
    if 'latitude' in org and 'longitude' in org:
        lat = float(org['latitude'])
        lon = float(org['longitude'])
        popup_content = f"<b>{org.get('name', 'N/A')}</b><br>{org.get('streetAddress', 'N/A')}<br>{org.get('postalCode', 'N/A')} {org.get('locality', 'N/A')}<br>Phone: {org.get('phone', 'N/A')}<br><a href='{org.get('url', '#')}' target='_blank'>WWW</a>"
        folium.Marker(
            location=[lat, lon],
            popup=popup_content,
            tooltip=org.get('name', 'N/A')
        ).add_to(mymap)

# Save map to file
map_file = 'output_map.html'
mymap.save(map_file)

print(f"Map file '{map_file}' has been saved successfully")
